@@ -52,7 +52,9 @@ public:
     virtual void exportXml(ticpp::Element* pConfig);
 
     const char* getID() { return id_m.c_str(); };
+    const char* getDescr() { return descr_m.c_str(); };
     const eibaddr_t getGad() { return gad_m; };
+    void read();
     virtual void onUpdate();
     void addChangeListener(ChangeListener* listener);
     void removeChangeListener(ChangeListener* listener);
@@ -60,13 +62,15 @@ public:
     virtual void setIntValue(int value) {};
     virtual void setFloatValue(float value) {};
     virtual void setBoolValue(bool value) {};
-    virtual int getIntValue() { return getBoolValue() ? 0 : 1; };
-    virtual float getFloatValue() { return getBoolValue() ? 0 : 1; };
+    virtual int getIntValue() { return getBoolValue() ? 1 : 0; };
+    virtual float getFloatValue() { return getBoolValue() ? 1 : 0; };
     virtual bool getBoolValue() { return false; };
+protected:
+    bool init_m;
 private:
     std::string id_m;
     eibaddr_t gad_m;
-    bool persist_m;
+    std::string initValue_m;
     std::string descr_m;
     typedef std::list<ChangeListener*> ListenerList_t;
     ListenerList_t listenerList_m;
@@ -82,9 +86,7 @@ public:
     virtual void setIntValue(int value);
     virtual void setFloatValue(float value);
     virtual void setBoolValue(bool value);
-    virtual int getIntValue() { return getBoolValue() ? 0 : 1; };
-    virtual float getFloatValue() { return getBoolValue() ? 0 : 1; };
-    virtual bool getBoolValue() { return value_m; };
+    virtual bool getBoolValue() { if (!init_m) read(); return value_m; };
 private:
     bool value_m;
 };
@@ -100,7 +102,7 @@ public:
     virtual void setFloatValue(float value);
     virtual void setBoolValue(bool value);
     virtual int getIntValue() { return (int)getFloatValue(); };
-    virtual float getFloatValue() { return value_m; };
+    virtual float getFloatValue() { if (!init_m) read(); return value_m; };
     virtual bool getBoolValue() { return getFloatValue() != 0; };
 private:
     float value_m;
@@ -116,9 +118,9 @@ public:
     virtual void setIntValue(int value);
     virtual void setFloatValue(float value);
     virtual void setBoolValue(bool value);
-    virtual int getIntValue() { return value_m; };
+    virtual int getIntValue() { if (!init_m) read(); return value_m; };
     virtual float getFloatValue() { return getIntValue(); };
-    virtual bool getBoolValue() { return getIntValue(); };
+    virtual bool getBoolValue() { return getIntValue() != 0; };
 private:
     int value_m;
 };
